BackspaceInputHandler class

Translates Backspace according to DEC Backarrow Key Mode (DECBKM).

Implemented types

Constructors

BackspaceInputHandler()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(TerminalKeyboardEvent event) → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited