onLineEvicted property
Called after a line is dropped from the front of lines because scrollback overflowed.
Implementation
final void Function(BufferLine line)? onLineEvicted;
Called after a line is dropped from the front of lines because scrollback overflowed.
final void Function(BufferLine line)? onLineEvicted;