BufferLine class
Methods
addCombiningCharacter (int index , int codePoint )
→ void
clearWideCellAt (int index , CursorStyle style )
→ void
copyFrom (BufferLine src , int srcCol , int dstCol , int len )
→ void
Copies len cells from src starting at srcCol to dstCol at this
line.
createAnchor (int offset )
→ CellAnchor
createCellData (int index )
→ CellData
dispose ()
→ void
eraseCell (int index , CursorStyle style )
→ void
eraseRange (int start , int end , CursorStyle style , {bool respectProtected = false })
→ void
Erase cells whose index satisfies start <= index < end. Erased cells
are filled with style.
getAttributes (int index )
→ int
getBackground (int index )
→ int
getCellData (int index , CellData cellData , {bool includeUnderlineColor = true })
→ void
getCodePoint (int index )
→ int
getCombiningCharacters (int index )
→ String ?
getContent (int index )
→ int
getForeground (int index )
→ int
getHyperlinkId (int index )
→ int
getSemanticContent (int index )
→ int
getText ([int ? from , int ? to ])
→ String
getTrimmedLength ([int ? cols ])
→ int
Returns the offset of the last cell that has content from the start of
the line.
getUnderlineColor (int index )
→ int
getWidth (int index )
→ int
insertCells (int start , int count , [CursorStyle ? style , int ? end ])
→ void
Inserts count cells at start. New cells are initialized with style.
isProtected (int index )
→ bool
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCells (int start , int count , [CursorStyle ? style , int ? end ])
→ void
Remove count cells starting at start. Cells that are empty after the
removal are filled with style.
resetCell (int index )
→ void
resize (int length )
→ void
setAsciiCells (int start , String text , int textStart , int count , CursorStyle style )
→ void
setAttributes (int index , int value )
→ void
setBackground (int index , int value )
→ void
setCell (int index , int char , int width , CursorStyle style )
→ void
setCellData (int index , CellData cellData )
→ void
setCodePoint (int index , int char )
→ void
setContent (int index , int value )
→ void
setForeground (int index , int value )
→ void
setSemanticContent (int index , int value )
→ void
setWidth (int index , int width )
→ void
toString ()
→ String
A string representation of this object.
override