BufferRange class abstract

Implementers

Constructors

BufferRange(CellOffset begin, CellOffset end)
const
BufferRange.collapsed(CellOffset begin)

Properties

begin → CellOffset
final
end → CellOffset
final
hashCode → int
The hash code for this object.
no setteroverride
isCollapsed → bool
no setter
isNormalized → bool
no setter
normalized → BufferRange
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(CellOffset position) → bool
Returns true if the givenposition is within this range.
extend(CellOffset position) → BufferRange
Returns the smallest range that contains both this range and the given position.
merge(BufferRange range) → BufferRange
Returns the smallest range that contains both this range and the given range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSegments() → Iterable<BufferSegment>
Convert this range to segments of single lines.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override