BufferRangeLine class

Inheritance

Properties

begin → CellOffset
finalinherited
end → CellOffset
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
isCollapsed → bool
no setterinherited
isNormalized → bool
no setterinherited
normalized → BufferRangeLine
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(CellOffset position) → bool
Returns true if the givenposition is within this range.
override
extend(CellOffset position) → BufferRangeLine
Returns the smallest range that contains both this range and the given position.
override
merge(BufferRange range) → BufferRangeLine
Returns the smallest range that contains both this range and the given range.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSegments() → Iterable<BufferSegment>
Convert this range to segments of single lines.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override