CellData class

Constructors

CellData({required int foreground, required int background, required int underlineColor, required int flags, required int content})
CellData.empty()
factory

Properties

background ↔ int
getter/setter pair
content ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
foreground ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hyperlinkId → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underlineColor ↔ int
getter/setter pair

Methods

getHash() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited