CursorStyle class

Constructors

CursorStyle({int foreground = 0, int background = 0, int underlineColor = 0, int attrs = 0, int hyperlinkId = 0, int semanticAttrs = 0})

Properties

attrs ↔ int
getter/setter pair
background ↔ int
getter/setter pair
foreground ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hyperlinkId ↔ int
getter/setter pair
no setter
isBold → bool
no setter
isDashedUnderline → bool
no setter
isDottedUnderline → bool
no setter
isDoubleUnderline → bool
no setter
isEncircled → bool
no setter
isFaint → bool
no setter
isFramed → bool
no setter
isInverse → bool
no setter
isInvisible → bool
no setter
isItalic → bool
no setter
isItalis → bool
no setter
isOverline → bool
no setter
isProtected → bool
no setter
isStrikethrough → bool
no setter
isUndercurl → bool
no setter
isUnderline → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticAttrs ↔ int
getter/setter pair
underlineColor ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
resetBackgroundColor() → void
resetForegroundColor() → void
resetUnderlineColor() → void
setBackgroundColor16(int color) → void
setBackgroundColor256(int color) → void
setBackgroundColorRgb(int r, int g, int b) → void
setBold() → void
setDashedUnderline() → void
setDottedUnderline() → void
setDoubleUnderline() → void
setEncircled() → void
setFaint() → void
setForegroundColor16(int color) → void
setForegroundColor256(int color) → void
setForegroundColorRgb(int r, int g, int b) → void
setFramed() → void
setInverse() → void
setInvisible() → void
setItalic() → void
setOverline() → void
setProtected() → void
setStrikethrough() → void
setUndercurl() → void
setUnderline() → void
setUnderlineColor256(int color) → void
setUnderlineColorRgb(int r, int g, int b) → void
toString() → String
A string representation of this object.
inherited
unsetBold() → void
unsetFaint() → void
unsetFrame() → void
unsetInverse() → void
unsetInvisible() → void
unsetItalic() → void
unsetOverline() → void
unsetProtected() → void
unsetStrikethrough() → void
unsetUnderline() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty → CursorStyle
final