unknownDCS abstract method
Called for a DCS payload that does not match any recognised DCS
request. payload is the raw text between the DCS introducer and the
string terminator.
Implementation
void unknownDCS(String payload);
Called for a DCS payload that does not match any recognised DCS
request. payload is the raw text between the DCS introducer and the
string terminator.
void unknownDCS(String payload);