TerminalMouseModifiers class

Constructors

TerminalMouseModifiers({bool shift = false, bool alt = false, bool control = false})
const

Properties

alt → bool
final
control → bool
final
hashCode → int
The hash code for this object.
no setterinherited
reportOffset → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shift → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const TerminalMouseModifiers