SuggestionPortalController class

Controls the location of the suggestion popup of SuggestionPortal.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
isShowing → bool
Whether the associated OverlayPortal should build and show its overlay child, using its overlayChildBuilder.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hide() → void
Hide the OverlayPortal's overlay child.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show() → void
Show the overlay child of the OverlayPortal this controller is attached to, at the top of the target Overlay.
inherited
toggle() → void
Convenience method for toggling the current isShowing status.
inherited
toString() → String
A string representation of this object.
inherited
update(Rect rect) → void
Updates the location of the suggestion popup to rect. If the popup is not showing, it will be shown after this call.

Operators

operator ==(Object other) → bool
The equality operator.
inherited