TerminalHighlight class

Constructors

TerminalHighlight(TerminalController owner, {required CellAnchor p1, required CellAnchor p2, required Color color})

Properties

color → Color
final
disposed → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
onDisposed → Event
no setterinherited
owner → TerminalController
final
p1 → CellAnchor
final
p2 → CellAnchor
final
range → BufferRange?
Returns the range of the highlight. May be null if the anchors that define the highlight are not attached to the terminal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rangeFor(Buffer buffer) → BufferRange?
Returns the highlight only when both anchors belong to buffer.
register(Disposable disposable) → void
inherited
registerCallback(void callback()) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited