paintedLines property
Total lines visited by the per-line paint loops, summed over paints.
Divided by paints this gives the average number of lines repainted per frame. Damage tracking is what would make this fall below the viewport height on a mostly static screen.
Implementation
static int paintedLines = 0;