paragraphCacheMisses property
Lookups in the shaped-text cache that had to shape and lay out the text.
Implementation
static int paragraphCacheMisses = 0;
Lookups in the shaped-text cache that had to shape and lay out the text.
static int paragraphCacheMisses = 0;