TerminalStyle class

Constructors

TerminalStyle({double fontSize = _kDefaultFontSize, double height = _kDefaultHeight, String fontFamily = _kDefaultFontFamily, List<String> fontFamilyFallback = _kDefaultFontFamilyFallback, bool drawBoldTextWithBrightColors = true, bool enableLigatures = false})
const
TerminalStyle.fromTextStyle(TextStyle textStyle)
factory

Properties

drawBoldTextWithBrightColors → bool
final
enableLigatures → bool
Whether glyph-merging font features are enabled.
final
fontFamily → String
final
fontFamilyFallback → List<String>
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setteroverride
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? fontSize, double? height, String? fontFamily, List<String>? fontFamilyFallback, bool? drawBoldTextWithBrightColors, bool? enableLigatures}) → TerminalStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTextStyle({Color? color, Color? backgroundColor, Color? decorationColor, bool bold = false, bool italic = false, bool underline = false, bool doubleUnderline = false, TextDecorationStyle decorationStyle = TextDecorationStyle.solid, bool strikethrough = false, bool overline = false}) → TextStyle

Operators

operator ==(Object other) → bool
The equality operator.
override