deleteDetection property

bool deleteDetection
final

Workaround to detect the delete key on platforms and IMEs that do not emit a hardware delete event. Preferred on mobile platforms. false by default.

Implementation

final bool deleteDetection;