ZModemFileInfo class

Constructors

ZModemFileInfo({required String pathname, int? length, int? modificationTime, String? mode, int? filesRemaining, int? bytesRemaining})

Properties

bytesRemaining → int?
final
filesRemaining → int?
final
hashCode → int
The hash code for this object.
no setterinherited
length → int?
final
mode → String?
final
modificationTime → int?
final
pathname → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited