TerminalSearchHighlight class

Constructors

TerminalSearchHighlight({required CellAnchor p1, required CellAnchor p2})

Properties

hashCode int
The hash code for this object.
no setterinherited
p1 CellAnchor
final
p2 CellAnchor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rangeFor(Buffer buffer) BufferRangeLine?
Returns the highlight only when both anchors belong to buffer.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited